package com.dcs.hnyz.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.dcs.hnyz.domain.AlarmEvent;

/**
 * 告警中心管理Mapper接口
 * 
 * @author hmy
 * @date 2025-04-30
 */
public interface AlarmEventMapper extends BaseMapper<AlarmEvent>
{
    /**
     * 查询告警中心管理
     * 
     * @param alarmId 告警中心管理主键
     * @return 告警中心管理
     */
    public AlarmEvent selectAlarmEventByAlarmId(Long alarmId);

    /**
     * 查询告警中心管理列表
     * 
     * @param alarmEvent 告警中心管理
     * @return 告警中心管理集合
     */
    public List<AlarmEvent> selectAlarmEventList(AlarmEvent alarmEvent);

    /**
     * 新增告警中心管理
     * 
     * @param alarmEvent 告警中心管理
     * @return 结果
     */
    public int insertAlarmEvent(AlarmEvent alarmEvent);

    /**
     * 修改告警中心管理
     * 
     * @param alarmEvent 告警中心管理
     * @return 结果
     */
    public int updateAlarmEvent(AlarmEvent alarmEvent);

    /**
     * 删除告警中心管理
     * 
     * @param alarmId 告警中心管理主键
     * @return 结果
     */
    public int deleteAlarmEventByAlarmId(Long alarmId);

    /**
     * 批量删除告警中心管理
     * 
     * @param alarmIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAlarmEventByAlarmIds(Long[] alarmIds);
}
